@@ -1,21 +1,3 @@
-/* spek-platform.cc
- *
- * Copyright (C) 2010-2012  Alexander Kojevnikov <alexander@kojevnikov.com>
- *
- * Spek is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Spek is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Spek.  If not, see <http://www.gnu.org/licenses/>.
- */
-
 #include <cstring>
 
 #ifdef OS_OSX
@@ -42,12 +24,18 @@ wxString spek_platform_config_path(const wxString& app_name)
 #ifdef OS_WIN
     wxFileName file_name(wxStandardPaths::Get().GetUserConfigDir(), wxEmptyString);
 #else
-    wxFileName file_name(wxGetHomeDir(), wxEmptyString);
-    file_name.AppendDir(wxT(".config"));
+    wxFileName file_name;
+    wxString xdg_config_home;
+    if (wxGetEnv("XDG_CONFIG_HOME", &xdg_config_home) && !xdg_config_home.IsEmpty()) {
+        file_name = wxFileName(xdg_config_home, wxEmptyString);
+    } else {
+        file_name = wxFileName(wxGetHomeDir(), wxEmptyString);
+        file_name.AppendDir(".config");
+    }
 #endif
     file_name.AppendDir(app_name);
     file_name.Mkdir(0755, wxPATH_MKDIR_FULL);
-    file_name.SetFullName(wxT("preferences"));
+    file_name.SetFullName("preferences");
     return file_name.GetFullPath();
 }
 
