@@ -1,21 +1,3 @@
-/* spek-preferences-dialog.cc
- *
- * Copyright (C) 2011-2012  Alexander Kojevnikov <alexander@kojevnikov.com>
- *
- * Spek is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Spek is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Spek.  If not, see <http://www.gnu.org/licenses/>.
- */
-
 #include "spek-platform.h"
 #include "spek-preferences.h"
 
@@ -26,21 +8,36 @@
 static const char *available_languages[] =
 {
     "", "",
+    "bs", "Bosanski",
+    "ca", "Català",
     "cs", "Čeština",
     "da", "Dansk",
     "de", "Deutsch",
+    "el", "Ελληνικά",
     "en", "English",
     "eo", "Esperanto",
     "es", "Español",
+    "fi", "Suomi",
     "fr", "Français",
+    "gl", "Galego",
+    "he", "עברית",
+    "hr", "Hrvatski",
+    "hu", "Magyar",
+    "id", "Bahasa Indonesia",
     "it", "Italiano",
     "ja", "日本語",
+    "ko", "한국어",
+    "lv", "Latviešu",
     "nb", "Norsk (bokmål)",
     "nl", "Nederlands",
+    "nn", "Norsk (nynorsk)",
     "pl", "Polski",
     "pt_BR", "Português brasileiro",
     "ru", "Русский",
+    "sk", "Slovenčina",
+    "sr@latin", "Srpski",
     "sv", "Svenska",
+    "th", "ไทย",
     "tr", "Türkçe",
     "uk", "Українська",
     "vi", "Tiếng Việt",
