@@ -1,21 +1,3 @@
-/* spek-preferences.cc
- *
- * Copyright (C) 2011-2012  Alexander Kojevnikov <alexander@kojevnikov.com>
- *
- * Spek is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Spek is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Spek.  If not, see <http://www.gnu.org/licenses/>.
- */
-
 #include <wx/string.h>
 
 #include "spek-platform.h"
@@ -44,12 +26,12 @@ void SpekPreferences::init()
         }
     }
     this->locale->Init(lang);
-    this->locale->AddCatalog(wxT(GETTEXT_PACKAGE));
+    this->locale->AddCatalog(GETTEXT_PACKAGE);
 }
 
 SpekPreferences::SpekPreferences() : locale(NULL)
 {
-    wxString path = spek_platform_config_path(wxT("spek"));
+    wxString path = spek_platform_config_path("spek");
     this->config = new wxFileConfig(
         wxEmptyString,
         wxEmptyString,
@@ -63,38 +45,38 @@ SpekPreferences::SpekPreferences() : locale(NULL)
 bool SpekPreferences::get_check_update()
 {
     bool result = true;
-    this->config->Read(wxT("/update/check"), &result);
+    this->config->Read("/update/check", &result);
     return result;
 }
 
 void SpekPreferences::set_check_update(bool value)
 {
-    this->config->Write(wxT("/update/check"), value);
+    this->config->Write("/update/check", value);
     this->config->Flush();
 }
 
 long SpekPreferences::get_last_update()
 {
     long result = 0;
-    this->config->Read(wxT("/update/last"), &result);
+    this->config->Read("/update/last", &result);
     return result;
 }
 
 void SpekPreferences::set_last_update(long value)
 {
-    this->config->Write(wxT("/update/last"), value);
+    this->config->Write("/update/last", value);
     this->config->Flush();
 }
 
 wxString SpekPreferences::get_language()
 {
-    wxString result(wxT(""));
-    this->config->Read(wxT("/general/language"), &result);
+    wxString result("");
+    this->config->Read("/general/language", &result);
     return result;
 }
 
 void SpekPreferences::set_language(const wxString& value)
 {
-    this->config->Write(wxT("/general/language"), value);
+    this->config->Write("/general/language", value);
     this->config->Flush();
 }
