@@ -1,29 +1,10 @@
-/* spek-spectrogram.cc
- *
- * Copyright (C) 2010-2013  Alexander Kojevnikov <alexander@kojevnikov.com>
- *
- * Spek is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Spek is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Spek.  If not, see <http://www.gnu.org/licenses/>.
- */
-
 #include <cmath>
 
 #include <wx/dcbuffer.h>
 
 #include "spek-audio.h"
 #include "spek-events.h"
-#include "spek-palette.h"
-#include "spek-pipeline.h"
+#include "spek-fft.h"
 #include "spek-platform.h"
 #include "spek-ruler.h"
 #include "spek-utils.h"
@@ -39,12 +20,13 @@ END_EVENT_TABLE()
 
 enum
 {
-    MAX_RANGE = 0,
     MIN_RANGE = -140,
-    URANGE = -20,
+    MAX_RANGE = 0,
+    URANGE = 0,
     LRANGE = -120,
-    NFFT = 2048,
-    BANDS = NFFT / 2 + 1,
+    FFT_BITS = 11,
+    MIN_FFT_BITS = 8,
+    MAX_FFT_BITS = 14,
     LPAD = 60,
     TPAD = 60,
     RPAD = 90,
@@ -55,6 +37,7 @@ enum
 
 // Forward declarations.
 static wxString trim(wxDC& dc, const wxString& s, int length, bool trim_end);
+static int bits_to_bands(int bits);
 
 SpekSpectrogram::SpekSpectrogram(wxFrame *parent) :
     wxWindow(
@@ -62,28 +45,27 @@ SpekSpectrogram::SpekSpectrogram(wxFrame *parent) :
         wxFULL_REPAINT_ON_RESIZE | wxWANTS_CHARS
     ),
     audio(new Audio()), // TODO: refactor
+    fft(new FFT()),
     pipeline(NULL),
+    streams(0),
+    stream(0),
+    channels(0),
+    channel(0),
+    window_function(WINDOW_DEFAULT),
     duration(0.0),
     sample_rate(0),
-    palette(RULER, BANDS),
+    palette(PALETTE_DEFAULT),
+    palette_image(),
     image(1, 1),
     prev_width(-1),
+    fft_bits(FFT_BITS),
     urange(URANGE),
     lrange(LRANGE)
 {
+    this->create_palette();
+
     SetBackgroundStyle(wxBG_STYLE_CUSTOM);
     SetFocus();
-
-    // Pre-draw the palette.
-    for (int y = 0; y < BANDS; y++) {
-        uint32_t color = spek_palette_spectrum(y / (double) BANDS);
-        this->palette.SetRGB(
-            wxRect(0, BANDS - y - 1, RULER, 1),
-            color >> 16,
-            (color >> 8) & 0xFF,
-            color & 0xFF
-        );
-    }
 }
 
 SpekSpectrogram::~SpekSpectrogram()
@@ -94,6 +76,8 @@ SpekSpectrogram::~SpekSpectrogram()
 void SpekSpectrogram::open(const wxString& path)
 {
     this->path = path;
+    this->stream = 0;
+    this->channel = 0;
     start();
     Refresh();
 }
@@ -109,20 +93,63 @@ void SpekSpectrogram::save(const wxString& path)
 
 void SpekSpectrogram::on_char(wxKeyEvent& evt)
 {
-    bool C = evt.GetModifiers() == wxMOD_CONTROL;
-    bool CS = evt.GetModifiers() == (wxMOD_CONTROL | wxMOD_SHIFT);
-    bool dn = evt.GetKeyCode() == WXK_DOWN;
-    bool up = evt.GetKeyCode() == WXK_UP;
-
-    if (C && up) {
+    switch (evt.GetKeyCode()) {
+    case 'c':
+        if (this->channels) {
+            this->channel = (this->channel + 1) % this->channels;
+        }
+        break;
+    case 'C':
+        if (this->channels) {
+            this->channel = (this->channel - 1 + this->channels) % this->channels;
+        }
+        break;
+    case 'f':
+        this->window_function = (enum window_function) ((this->window_function + 1) % WINDOW_COUNT);
+        break;
+    case 'F':
+        this->window_function =
+            (enum window_function) ((this->window_function - 1 + WINDOW_COUNT) % WINDOW_COUNT);
+        break;
+    case 'l':
         this->lrange = spek_min(this->lrange + 1, this->urange - 1);
-    } else if (C && dn) {
+        break;
+    case 'L':
         this->lrange = spek_max(this->lrange - 1, MIN_RANGE);
-    } else if (CS && up) {
+        break;
+    case 'p':
+        this->palette = (enum palette) ((this->palette + 1) % PALETTE_COUNT);
+        this->create_palette();
+        break;
+    case 'P':
+        this->palette = (enum palette) ((this->palette - 1 + PALETTE_COUNT) % PALETTE_COUNT);
+        this->create_palette();
+        break;
+    case 's':
+        if (this->streams) {
+            this->stream = (this->stream + 1) % this->streams;
+        }
+        break;
+    case 'S':
+        if (this->streams) {
+            this->stream = (this->stream - 1 + this->streams) % this->streams;
+        }
+        break;
+    case 'u':
         this->urange = spek_min(this->urange + 1, MAX_RANGE);
-    } else if (CS && dn) {
+        break;
+    case 'U':
         this->urange = spek_max(this->urange - 1, this->lrange + 1);
-    } else {
+        break;
+    case 'w':
+        this->fft_bits = spek_min(this->fft_bits + 1, MAX_FFT_BITS);
+        this->create_palette();
+        break;
+    case 'W':
+        this->fft_bits = spek_max(this->fft_bits - 1, MIN_FFT_BITS);
+        this->create_palette();
+        break;
+    default:
         evt.Skip();
         return;
     }
@@ -164,7 +191,7 @@ void SpekSpectrogram::on_have_sample(SpekHaveSampleEvent& event)
     for (int y = 0; y < bands; y++) {
         double value = fmin(this->urange, fmax(this->lrange, values[y]));
         double level = (value - this->lrange) / range;
-        uint32_t color = spek_palette_spectrum(level);
+        uint32_t color = spek_palette(this->palette, level);
         this->image.SetRGB(
             sample,
             bands - y - 1,
@@ -181,7 +208,7 @@ void SpekSpectrogram::on_have_sample(SpekHaveSampleEvent& event)
 static wxString time_formatter(int unit)
 {
     // TODO: i18n
-    return wxString::Format(wxT("%d:%02d"), unit / 60, unit % 60);
+    return wxString::Format("%d:%02d", unit / 60, unit % 60);
 }
 
 static wxString freq_formatter(int unit)
@@ -218,27 +245,27 @@ void SpekSpectrogram::render(wxDC& dc)
     wxFont small_font = wxFont(normal_font);
     small_font.SetPointSize((int)round(8 * spek_platform_font_scale()));
     dc.SetFont(normal_font);
-    int normal_height = dc.GetTextExtent(wxT("dummy")).GetHeight();
+    int normal_height = dc.GetTextExtent("dummy").GetHeight();
     dc.SetFont(large_font);
-    int large_height = dc.GetTextExtent(wxT("dummy")).GetHeight();
+    int large_height = dc.GetTextExtent("dummy").GetHeight();
     dc.SetFont(small_font);
-    int small_height = dc.GetTextExtent(wxT("dummy")).GetHeight();
+    int small_height = dc.GetTextExtent("dummy").GetHeight();
 
     // Clean the background.
     dc.Clear();
 
     // Spek version
     dc.SetFont(large_font);
-    wxString package_name(wxT(PACKAGE_NAME));
+    wxString package_name(PACKAGE_NAME);
     dc.DrawText(
         package_name,
         w - RPAD + GAP,
         TPAD - 2 * GAP - normal_height - large_height
     );
-    int package_name_width = dc.GetTextExtent(package_name + wxT(" ")).GetWidth();
+    int package_name_width = dc.GetTextExtent(package_name + " ").GetWidth();
     dc.SetFont(small_font);
     dc.DrawText(
-        wxT(PACKAGE_VERSION),
+        PACKAGE_VERSION,
         w - RPAD + GAP + package_name_width,
         TPAD - 2 * GAP - normal_height - small_height
     );
@@ -276,7 +303,7 @@ void SpekSpectrogram::render(wxDC& dc)
                 h - BPAD,
                 SpekRuler::BOTTOM,
                 // TODO: i18n
-                wxT("00:00"),
+                "00:00",
                 time_factors,
                 0,
                 (int)this->duration,
@@ -315,7 +342,7 @@ void SpekSpectrogram::render(wxDC& dc)
 
     // The palette.
     if (h - TPAD - BPAD > 0) {
-        wxBitmap bmp(this->palette.Scale(RULER, h - TPAD - BPAD + 1));
+        wxBitmap bmp(this->palette_image.Scale(RULER, h - TPAD - BPAD + 1));
         dc.DrawBitmap(bmp, w - RPAD + GAP, TPAD);
 
         // Prepare to draw the ruler.
@@ -341,9 +368,9 @@ void SpekSpectrogram::render(wxDC& dc)
     }
 }
 
-static void pipeline_cb(int sample, float *values, void *cb_data)
+static void pipeline_cb(int bands, int sample, float *values, void *cb_data)
 {
-    SpekHaveSampleEvent event(BANDS, sample, values, false);
+    SpekHaveSampleEvent event(bands, sample, values, false);
     SpekSpectrogram *s = (SpekSpectrogram *)cb_data;
     wxPostEvent(s, event);
 }
@@ -362,10 +389,13 @@ void SpekSpectrogram::start()
     wxSize size = GetClientSize();
     int samples = size.GetWidth() - LPAD - RPAD;
     if (samples > 0) {
-        this->image.Create(samples, BANDS);
+        this->image.Create(samples, bits_to_bands(this->fft_bits));
         this->pipeline = spek_pipeline_open(
-            this->audio->open(std::string(this->path.utf8_str())),
-            BANDS,
+            this->audio->open(std::string(this->path.utf8_str()), this->stream),
+            this->fft->create(this->fft_bits),
+            this->stream,
+            this->channel,
+            this->window_function,
             samples,
             pipeline_cb,
             this
@@ -373,6 +403,8 @@ void SpekSpectrogram::start()
         spek_pipeline_start(this->pipeline);
         // TODO: extract conversion into a utility function.
         this->desc = wxString::FromUTF8(spek_pipeline_desc(this->pipeline).c_str());
+        this->streams = spek_pipeline_streams(this->pipeline);
+        this->channels = spek_pipeline_channels(this->pipeline);
         this->duration = spek_pipeline_duration(this->pipeline);
         this->sample_rate = spek_pipeline_sample_rate(this->pipeline);
     } else {
@@ -391,6 +423,20 @@ void SpekSpectrogram::stop()
     }
 }
 
+void SpekSpectrogram::create_palette()
+{
+    this->palette_image.Create(RULER, bits_to_bands(this->fft_bits));
+    for (int y = 0; y < bits_to_bands(this->fft_bits); y++) {
+        uint32_t color = spek_palette(this->palette, y / (double)bits_to_bands(this->fft_bits));
+        this->palette_image.SetRGB(
+            wxRect(0, bits_to_bands(this->fft_bits) - y - 1, RULER, 1),
+            color >> 16,
+            (color >> 8) & 0xFF,
+            color & 0xFF
+        );
+    }
+}
+
 // Trim `s` so that it fits into `length`.
 static wxString trim(wxDC& dc, const wxString& s, int length, bool trim_end)
 {
@@ -405,7 +451,7 @@ static wxString trim(wxDC& dc, const wxString& s, int length, bool trim_end)
     }
 
     // Binary search FTW!
-    wxString fix(wxT("..."));
+    wxString fix("...");
     int i = 0;
     int k = s.length();
     while (k - i > 1) {
@@ -420,3 +466,8 @@ static wxString trim(wxDC& dc, const wxString& s, int length, bool trim_end)
 
     return trim_end ? s.substr(0, i) + fix : fix + s.substr(k);
 }
+
+// TODO: test
+static int bits_to_bands(int bits) {
+    return (1 << (bits - 1)) + 1;
+}
