@@ -1,21 +1,3 @@
-/* spek.cc
- *
- * Copyright (C) 2010-2012  Alexander Kojevnikov <alexander@kojevnikov.com>
- *
- * Spek is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Spek is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Spek.  If not, see <http://www.gnu.org/licenses/>.
- */
-
 #include <wx/cmdline.h>
 #include <wx/log.h>
 #include <wx/socket.h>
@@ -57,29 +39,27 @@ bool Spek::OnInit()
 
     static const wxCmdLineEntryDesc desc[] = {{
             wxCMD_LINE_SWITCH,
-            wxT_2("h"),
-            wxT_2("help"),
-            wxT_2("Show this help message"),
+            "h",
+            "help",
+            "Show this help message",
             wxCMD_LINE_VAL_NONE,
-            wxCMD_LINE_OPTION_HELP
+            wxCMD_LINE_OPTION_HELP,
         }, {
             wxCMD_LINE_SWITCH,
-            wxT_2("V"),
-            wxT_2("version"),
-            wxT_2("Display the version and exit"),
+            "V",
+            "version",
+            "Display the version and exit",
             wxCMD_LINE_VAL_NONE,
-            wxCMD_LINE_PARAM_OPTIONAL
+            wxCMD_LINE_PARAM_OPTIONAL,
         }, {
             wxCMD_LINE_PARAM,
             NULL,
             NULL,
-            wxT_2("FILE"),
+            "FILE",
             wxCMD_LINE_VAL_STRING,
-            wxCMD_LINE_PARAM_OPTIONAL
-        }, {
-            // TODO: use wxCMD_LINE_DESC_END after settling on wx29.
-            wxCMD_LINE_NONE, NULL, NULL, NULL, wxCMD_LINE_VAL_NONE, 0
-        }
+            wxCMD_LINE_PARAM_OPTIONAL,
+        },
+        wxCMD_LINE_DESC_END,
     };
 
     wxCmdLineParser parser(desc, argc, argv);
@@ -91,10 +71,10 @@ bool Spek::OnInit()
         this->quit = true;
         return true;
     }
-    if (parser.Found(wxT("version"))) {
+    if (parser.Found("version")) {
         // TRANSLATORS: the %s is the package version.
-        wxPrintf(_("Spek version %s"), wxT(PACKAGE_VERSION));
-        wxPrintf(wxT("\n"));
+        wxPrintf(_("Spek version %s"), PACKAGE_VERSION);
+        wxPrintf("\n");
         this->quit = true;
         return true;
     }
